==> orthanc_0.7.5%2Bdfsg.orig.tar.xz: Orthanc-0.7.5/Core/HttpServer/HttpHandler.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2014 Medical Physics Department, CHU of Liege,
 * Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include <map>
#include <vector>
#include <stdint.h>
#include "../Toolbox.h"

namespace Orthanc
{
  class HttpOutput;

  class HttpHandler
  {
  public:
    typedef std::map<std::string, std::string> Arguments;

    virtual ~HttpHandler()
    {
    }

    virtual bool IsServedUri(const UriComponents& uri) = 0;

    virtual void Handle(HttpOutput& output,
                        HttpMethod method,
                        const UriComponents& uri,
                        const Arguments& headers,
                        const Arguments& getArguments,
                        const std::string& postData) = 0;

    static void ParseGetQuery(HttpHandler::Arguments& result, 
                              const char* query);

    static std::string GetArgument(const Arguments& getArguments,
                                   const std::string& name,
                                   const std::string& defaultValue);

    static void ParseCookies(HttpHandler::Arguments& result, 
                             const HttpHandler::Arguments& httpHeaders);
  };
}

==> orthanc_0.9.0%2Bdfsg.orig.tar.xz: Orthanc-0.9.0/Core/HttpServer/HttpHandler.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2015 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include <map>
#include <vector>
#include <stdint.h>
#include "../Toolbox.h"

namespace Orthanc
{
  class HttpOutput;

  class HttpHandler
  {
  public:
    typedef std::map<std::string, std::string>                  Arguments;
    typedef std::vector< std::pair<std::string, std::string> >  GetArguments;

    virtual ~HttpHandler()
    {
    }

    virtual bool Handle(HttpOutput& output,
                        HttpMethod method,
                        const UriComponents& uri,
                        const Arguments& headers,
                        const GetArguments& getArguments,
                        const std::string& postData) = 0;

    static void ParseGetArguments(HttpHandler::GetArguments& result, 
                                  const char* query);

    static void ParseGetQuery(UriComponents& uri,
                              HttpHandler::GetArguments& getArguments, 
                              const char* query);

    static std::string GetArgument(const Arguments& getArguments,
                                   const std::string& name,
                                   const std::string& defaultValue);

    static std::string GetArgument(const GetArguments& getArguments,
                                   const std::string& name,
                                   const std::string& defaultValue);

    static void ParseCookies(HttpHandler::Arguments& result, 
                             const HttpHandler::Arguments& httpHeaders);

    static void CompileGetArguments(Arguments& compiled,
                                    const GetArguments& source);
  };
}
